#[non_exhaustive]pub enum InvalidRequest {
FormAndBody,
CookieOctet,
ConnectUnsupported,
}Expand description
Bad request construction (illegal cookie octets, form fields plus an explicit body, …).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FormAndBody
Both form fields and an explicit body were set.
CookieOctet
Cookie name or value contained ; or a control octet.
ConnectUnsupported
CONNECT needs authority-form + a tunneled socket (RFC 9112 3.2.3 / 9.3.6); not supported yet.